ForkWorkerHandle: wraps two Framed Unix streams for a forked child.
Similar to PipeWorkerHandle but the child is identified by PID (not
a tokio::process::Child), since the PHP master owns the forked process.
ForkWorkerHandle: wraps two Framed Unix streams for a forked child.
Similar to PipeWorkerHandle but the child is identified by PID (not
a tokio::process::Child), since the PHP master owns the forked process.